@@ -584,12 +584,17 @@ handle_button_press (GtkWidget *button,
             g_print("handle_button_press : calling update_status_and_buttons\n");
 #endif
             update_status_and_buttons(self);
-	    /* ToDo: verify that this is the function that stucks
-	     * and causes the widget not to respond anymore */
-	    /* location_gps_device_reset_last_known(self->device); */
-            location_gpsd_control_start(self->control);
 	    /* open a new log file */
 	    logfile_start(self);
+#ifdef DEBUG
+    if (self->logfile) {
+        g_fprintf(self->logfile, "%s -- calling location_gpsd_control_start\n", __func__);
+	fflush(self->logfile);
+    }
+#endif
+            location_gpsd_control_start(self->control);
+	    g_usleep(500);
+	    location_gps_device_reset_last_known(self->device);
 	}
 	else if (self->app_state == APP_STATE_RECORDING) {
             self->app_state = APP_STATE_PAUSED;
@@ -656,6 +661,7 @@ on_button_release(GtkWidget* widget, GdkEventButton *button_event, gpointer data
     self->rec_button_down = FALSE;
     self->stop_button_down = FALSE;
     gtk_widget_queue_draw(GTK_WIDGET(self));
+    g_usleep(500);
 
     if (widget == GTK_WIDGET(self->background)) {
         if (button_event->x >= self->button_rec->allocation.x &&
@@ -809,6 +815,13 @@ on_start(LocationGPSDControl *control, gpointer data)
 #ifndef __arm__
         g_printf("%s\n", __func__);
 #endif
+#ifdef DEBUG
+    GpsDataLoggerWidget *self = GPS_DATA_LOGGER_WIDGET (data);
+    if (self->logfile) {
+        g_fprintf(self->logfile, "%s -- was here\n", __func__);
+	fflush(self->logfile);
+    }
+#endif
 }
 
 static void
@@ -817,6 +830,12 @@ on_stop(LocationGPSDControl *control, gpointer data)
 	GpsDataLoggerWidget *self = GPS_DATA_LOGGER_WIDGET (data);
 #ifndef __arm__
         g_printf("%s\n", __func__);
+#endif
+#ifdef DEBUG
+    if (self->logfile) {
+        g_fprintf(self->logfile, "%s -- enter\n", __func__);
+	fflush(self->logfile);
+    }
 #endif
 	if (self->app_state == APP_STATE_STOPPING) {
         	hildon_banner_show_information(NULL,
@@ -825,6 +844,12 @@ on_stop(LocationGPSDControl *control, gpointer data)
 		self->app_state = APP_STATE_IDLE;
 #ifndef __arm__
                 g_print("on_stop : calling update_status_and_buttons\n");
+#endif
+#ifdef DEBUG
+            if (self->logfile) {
+                g_fprintf(self->logfile, "%s -- going to IDLE, calling update_status_and_buttons\n", __func__);
+	        fflush(self->logfile);
+            }
 #endif
 		update_status_and_buttons(self);
 	}
